.. title:: User guide: contents

..
    We are putting the title as a raw HTML so that it doesn't appear in
    the contents

.. raw:: html

    <h1>User guide: contents</h1>

.. _user_guide:

.. include:: ../includes/big_toc_css.rst

.. toctree::
   :numbered:
   :maxdepth: 2

   introduction
   installation
   datasets
   density_estimation
   clustering
   correlation_functions
   dimensionality
   regression
   classification
   time_series
   ../modules/classes
   resources
